@@ -5,7 +5,7 @@ use warnings;
 use parent 'Perl::Critic::Policy';
 use Perl::Critic::Utils ':severities';
 
-$Perl::Critic::Policy::Variables::RequireHungarianNotation::VERSION = '0.0.2';
+$Perl::Critic::Policy::Variables::RequireHungarianNotation::VERSION = '0.0.3';
 
 sub desc {
     return 'Non hungarian notation';
@@ -17,13 +17,14 @@ sub expl {
 
 sub supported_parameters {
     return (
-        { name => 'array',     description => 'Prefix for Hash vars',                      default_string => q/a_/, },
-        { name => 'hash',      description => 'Prefix for Array vars',                     default_string => q/h_/, },
+        { name => 'array',     description => 'Prefix for Array vars',                     default_string => q/a_/, },
+        { name => 'hash',      description => 'Prefix for Hash vars',                      default_string => q/h_/, },
         { name => 'array_ref', description => 'Prefix for Arrayref vars',                  default_string => q/ar_/, },
         { name => 'hash_ref',  description => 'Prefix for Hashref vars',                   default_string => q/hr_/, },
-        { name => 'code_ref',  description => 'Prefix for Hashref vars',                   default_string => q/cr_/, },
+        { name => 'code_ref',  description => 'Prefix for Coderef vars',                   default_string => q/cr_/, },
         { name => 'object',    description => 'Prefix for Object vars',                    default_string => q/o_/, },
         { name => 'integer',   description => 'Prefix for Integer vars',                   default_string => q/i_/, },
+        { name => 'float',     description => 'Prefix for Float vars',                     default_string => q/f_/, },
         { name => 'string',    description => 'Prefix for String vars',                    default_string => q/s_/, },
         { name => 'boolean',   description => 'Prefix for boolean vars',                   default_string => q/b_/ },
         { name => 'regex',     description => 'Prefix for predefined regular expressions', default_string => q/rx_/ },
@@ -97,7 +98,7 @@ sub _check_sub_variables {
 sub _b_check_scalar {
     my ( $self, $s_symbol, $s_raw_type ) = @_;
     return 1 if $s_symbol eq q/$/ . $self->{_self};
-    for (qw/array_ref hash_ref object integer string boolean regex/) {
+    for (qw/array_ref hash_ref object integer float string boolean regex code_ref/) {
         return 1 if $self->_check_prefix( $s_symbol, q/$/, $_ );
     }
     if ( $self->{_custom} ) {
@@ -126,11 +127,11 @@ __END__
 
 =head1 NAME
 
-Perl::Critic::Policy::Variables::RequireHungarianNotation - prohibit hungarian notation
+Perl::Critic::Policy::Variables::RequireHungarianNotation - Critic policy for hungarian notation.
 
 =head1 VERSION
 
-Version 0.0.2
+Version 0.0.3
 
 =head1 SYNOPSIS
 
@@ -143,7 +144,15 @@ Don't clutter your code with unnecessary variable initialization:
     my $hashref  = {};    # or this
     my $arrayref = [];    # or this
     my $string   = '';    # or this
-    
+
+The policy is also running through sub declarations.    
+
+    # won't work
+    sub some_sub {
+        my ($self, $arrayref, $string) = @_;
+        ...
+    }
+
 Instead, do this:
 
     my @a_array     = (); # do this
@@ -152,6 +161,14 @@ Instead, do this:
     my $hr_arrayref = []; # and this
     my $s_string    = ''; # and this
 
+    # this will (hopefuly)
+    sub some_sub {
+        my ($self, $ar_arrayref, $s_string) = @_;
+        ...
+    }
+
+$self as variable is excluded.
+
 =head1 SUBROUTINES/METHODS
 
 =head2 expl()
@@ -159,6 +176,10 @@ Instead, do this:
 Returns a string containing an explanation of this policy.
 
 =head2 supported_parameters
+ 
+Return an array with information about the parameters supported.
+ 
+    my @supported_parameters = $policy->supported_parameters();
 
 =head2 default_severity
 
@@ -174,12 +195,14 @@ Returns a string describing the elements to which this policy applies.
 
 =head2 violates
 
-Method to determine if the element currently under scrutiny violates this
-policy.  If it does, return a properly constructed C<Perl::Critic::Violation>
-object.  Otherwise, return C<undef>.
+Check an element for violations against this policy.
+ 
+    my $o_policy->violates( $o_element, $o_document );
 
 =head2 desc()
 
+Returns a string containing a sort description of this policy.
+
 =head1 INTERFACE 
 
 =for author to fill in:
@@ -187,37 +210,107 @@ object.  Otherwise, return C<undef>.
 
 =head1 DIAGNOSTICS
 
-=for author to fill in:
-    List every single error and warning message that the module can
-    generate (even the ones that will "never happen"), with a full
-    explanation of each problem, one or more likely causes, and any
-    suggested remedies.
-
-=over
-
-=item C<< Error message here, perhaps with %s placeholders >>
-
-[Description of error here]
-
-=item C<< Another error message here >>
-
-[Description of error here]
-
-[Et cetera, et cetera]
-
-=back
-
-
 =head1 CONFIGURATION AND ENVIRONMENT
 
-Perl::Critic::Policy::Variables::RequireHungarianNotation requires no configuration files or environment variables.
+Each prefix is full configurable for it's own
+
+=head2 array
+
+Prefix for Array vars.
+
+    [Variables::RequireHungarianNotation]
+    array = a_
+
+=head2 hash
+
+Prefix for Hash vars.
+
+    [Variables::RequireHungarianNotation]
+    hash = h_
+
+=head2 array_ref
+
+Prefix for Arrayref vars.
+
+    [Variables::RequireHungarianNotation]
+    array_ref = ar_
+
+=head2 hash_ref
+
+Prefix for Hashref vars.
+
+    [Variables::RequireHungarianNotation]
+    hash_ref = hr_
+
+=head2 code_ref
+
+Prefix for Coderef vars.
+
+    [Variables::RequireHungarianNotation]
+    code_ref = cr_
+
+=head2 object
+
+Prefix for Object vars.
+
+    [Variables::RequireHungarianNotation]
+    object = o_
+
+=head2 integer
+
+Prefix for Integer vars.
+
+    [Variables::RequireHungarianNotation]
+    integer = i_
+
+=head2 float
+
+Prefix for Float vars.
+
+    [Variables::RequireHungarianNotation]
+    float = f_
+
+=head2 string
+
+Prefix for String vars.
+
+    [Variables::RequireHungarianNotation]
+    string = s_
+
+=head2 boolean
+
+Prefix for Boolean vars.
+
+    [Variables::RequireHungarianNotation]
+    boolean = b_
+
+=head2 regex
+
+Prefix for predefined regular expressions.
+
+    [Variables::RequireHungarianNotation]
+    regex = rx_
+
+=head2 self
+
+Ingore self is the class variable for it's own.
+
+    [Variables::RequireHungarianNotation]
+    self = this
+
+=head2 custom
+
+A space-separated list of methods that are known to always return a safely
+quoted result.
+
+    [Variables::RequireHungarianNotation]
+    custom = inv obj any
 
 
 =head1 DEPENDENCIES
 
 L<Perl::Critic::Policy|Perl::Critic::Policy>, L<Perl::Critic::Utils|Perl::Critic::Utils>
 
-
 =head1 INCOMPATIBILITIES
 
 None reported.
